@@ -7,6 +7,8 @@ describe Module do
       module ModBar
         module Noo
           module Too
+            module Boo
+            end
           end
         end
       end
@@ -45,9 +47,19 @@ describe Module do
   end
 
   it "should find nested constants on nested constants" do
-    Foo::ModBar.find_const('Noo::Too')
+    Foo::ModBar.find_const('Noo::Too').should == Foo::ModBar::Noo::Too
   end
 
+  it "should find constants outside of nested constants" do
+    Foo::ModBar::Noo::Too.find_const("Zed").should == Foo::Zed
+  end
+
+  it 'should be able to find past the second nested level' do
+    Foo::ModBar::Noo.find_const('Too').should == Foo::ModBar::Noo::Too
+    Foo::ModBar::Noo::Too.find_const('Boo').should == Foo::ModBar::Noo::Too::Boo
+  end
+
+
   it "should be able to deal with constants being added and removed" do
     Object.find_const('Bar') # First we load Bar with find_const
     Object.module_eval { remove_const('Bar') } # Now we delete it
